@@ -1,5 +1,5 @@
 #
-# GdkImlib: An interface to gdk_imlib to go with Gtkinter.  It wraps the
+# GdkImlib: An interface to gdk_imlib to go with gtk.py.  It wraps the
 #           native module _gdkimlib.  It is sugested that you import it as
 #           "import GdkImlib".
 #
@@ -15,7 +15,7 @@
 
 import _gdkimlib
 
-from Gtkinter import GtkPixmap
+from gtk import GtkPixmap
 
 #some constants ...
 RT_PLAIN_PALETTE       = 0
