@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 
 #   Interactive Python-GTK Console
 #   Copyright (C), 1998 James Henstridge <james@daa.com.au>
@@ -29,7 +29,7 @@
 
 import sys, string, traceback
 #sys.path.append('/home/james/.gimp/plug-ins')
-from Gtkinter import *
+from gtk import *
 
 stdout = sys.stdout
 
