@@ -2,7 +2,7 @@
 
 import profile, pstats, fpformat
 
-from Gtkinter import *
+from gtk import *
 
 class PStatWindow(GtkWindow):
 	def __init__(self, stats):
