@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 #
 # Test the GtkMenuBar, GtkMenu and GtkMenuItem, GtkList and
 # GtkListItem, GtkFileSelection objects
@@ -6,7 +6,7 @@
 
 import sys
 import time
-from Gtkinter import *
+from gtk import *
 
 class Application:		
 	def __init__(self, argv):
@@ -42,22 +42,28 @@ class Application:
 	
 
 	def init_menu(self):
-                self.w_menubar=GtkExtra.MenuFactory()
-                self.w_menubar.add_entries([
-                        ('File/New',        None, self.process_file_new),
-                        ('File/Open...',    None, self.process_file_open),
-                        ('File/Save',       None, self.process_file_save),
-                        ('File/Save As...', None, self.process_file_save_as),
-                        ('File/Close',      None, self.process_file_close),
-                        ('File/<separator>',None, None),
-                        ('File/Exit',       None, self.process_file_exit),
-
-                        ('Edit/Cut',   None, self.process_edit_cut),
-                        ('Edit/Copy',  None, self.process_edit_copy),
-                        ('Edit/Paste', None, self.process_edit_paste),
-                ])
-                self.w_vbox.pack_start(self.w_menubar, expand=FALSE)
-                self.w_menubar.show()
+		ag = GtkAccelGroup()
+		itemf = GtkItemFactory(GtkMenuBar, "<main>", ag)
+		self.w_window.add_accel_group(ag)
+		file_cb = self.process_file
+		edit_cb = self.process_edit
+		itemf.create_items([
+			('/_File',          None,         None, 0, '<Branch>'),
+			('/_File/_New',     '<control>N', file_cb, 1, ''),
+			('/_File/_Open',    '<control>O', file_cb, 2, ''),
+			('/_File/_Save',    '<control>S', file_cb, 3, ''),
+			('/_File/Save _As', None,         file_cb, 4, ''),
+			('/_File/_Close',   None,         file_cb, 5, ''),
+			('/_File/sep1',     None,   file_cb, 0, '<Separator>'),
+			('/_File/E_xit',    '<alt>F4',    file_cb, 6, ''),
+			('/_Edit',          None,         None, 0, '<Branch>'),
+			('/_Edit/C_ut',     '<control>X', edit_cb, 1, ''),
+			('/_Edit/_Copy',    '<control>C', edit_cb, 2, ''),
+			('/_Edit/_Paste',   '<control>V', edit_cb, 3, '')
+		])
+		self.w_menubar = itemf.get_widget('<main>')
+		self.w_vbox.pack_start(self.w_menubar, expand=FALSE)
+		self.w_menubar.show()
 
 	def init_list(self):		
 		c=GtkScrolledWindow()	
@@ -89,37 +95,21 @@ class Application:
 		b2.show()
 		t.show()
 
-	def process_file_new(self, mi):
-		print "process_file_new"
-		
-	def process_file_open(self, mi):
-		print "process_file_open"
-		# how to transform this in modal dialog is myterious...
-		fs=GtkFileSelection()
-		fs.ok_button.connect('clicked', fs.destroy)
-		fs.show()
-		
-	def process_file_save(self, mi):
-		print "process_file_save"
-		
-	def process_file_save_as(self, mi):
-		print "process_file_save_as"
-		# how to transform this in modal dialog is myterious...
-		fs=GtkFileSelection()
-		fs.show()
-		
-	def process_file_close(self, mi):
-		print "process_file_close"
-		
-	def process_edit_cut(self, mi):
-		print "process_edit_cut"
-		
-	def process_edit_copy(self, mi):
-		print "process_edit_copy"
-		
-	def process_edit_paste(self, mi):
-		print "process_edit_paste"
-		
+	def process_file(self, action, widget):
+		if action == 0: print "unknown"
+		elif action == 1: print "File:New"
+		elif action == 2: print "File:Open"
+		elif action == 3: print "File:Save"
+		elif action == 4: print "File:Save As"
+		elif action == 5: print "File:Close"
+		elif action == 6:
+			print "File:Exit"
+			mainquit()
+	def process_edit(self, action, widget):
+		if action == 0: print "Edit:<unknown>"
+		elif action == 1: print "Edit:Cut"
+		elif action == 2: print "Edit:Copy"
+		elif action == 3: print "Edit:Paste"
 	
 	def idle(self):
 		self.idlecount = self.idlecount + 1
