@@ -5,7 +5,7 @@
 
 import sys
 import time
-from Gtkinter import *
+from gtk import *
 import GtkExtra
 				
 class Application:		
