@@ -1,6 +1,6 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 
-from Gtkinter import *
+from gtk import *
 
 def destroy(args):
 	window.destroy()
