@@ -1,9 +1,9 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 
 # this is a translation of "Hello World III" from the GTK manual,
-# using Gtkinter
+# using gtk.py
 
-from Gtkinter import *
+from gtk import *
 
 def hello(*args):
     print "Hello World"
