@@ -3,7 +3,7 @@
 #this is a simple translation of the scribble example that comes with GTK+
 
 import sys
-from Gtkinter import *
+from gtk import *
 
 pixmap = None
 
