@@ -4,7 +4,6 @@
 # with gtkmodule.  Also implements a tooltip for the button.
 
 from _gtk import *
-from _gtkbase import *
 from GTK import *
 
 def hello(*args):
@@ -16,7 +15,6 @@ def destroy(*args):
 	gtk_main_quit()
 
 gtk_init()
-pygtk_init()
 
 tt = gtk_tooltips_new()
 gtk_tooltips_set_delay(tt, 500)
