@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-from Gtkinter import *
+from gtk import *
 import GtkExtra
 
 wins = {}
