@@ -8,7 +8,7 @@ generators are sufficiently general).
 
 import sys
 import string
-from Gtkinter import *
+from gtk import *
 # the style sheet generator
 import style
 
